@@ -5,7 +5,7 @@ this.stylize = function stylize(str, style) {
     if (module.exports.nocolor) {
       return str;
     }
-    
+
     var styles = {
         'bold'      : [1,  22],
         'italic'    : [3,  23],
@@ -52,6 +52,8 @@ this.puts = function (options) {
     };
 };
 
+this.log = this.puts({});
+
 this.result = function (event) {
     var result = [], buffer = [], time = '', header;
     var complete = event.honored + event.pending + event.errored + event.broken;
@@ -93,7 +95,7 @@ this.inspect = function inspect(val) {
     if (module.exports.nocolor) {
       return eyes(val);
     }
-    
+
     return '\033[1m' + eyes(val) + '\033[22m';
 };
 
@@ -129,7 +131,7 @@ this.vowText = function (event) {
     if (event.status === 'broken') {
         buffer.push('      » ' + event.exception);
     } else if (event.status === 'errored') {
-        if (event.exception.type === 'promise') {
+        if (event.exception.type === 'emitter') {
             buffer.push('      » ' + this.stylize("An unexpected error was caught: " +
                            this.stylize(event.exception.error, 'bold'), 'red'));
         } else {
