@@ -26,7 +26,7 @@ this.report = function (data) {
             puts(console.vowText(event));
             break;
         case 'end':
-            util.print('\n');
+            this.print('\n');
             break;
         case 'finish':
             puts(console.result(event).join('\n'));
@@ -38,5 +38,5 @@ this.report = function (data) {
 };
 
 this.print = function (str) {
-    util.print(str);
+    process.stdout.write(str);
 };
