@@ -56,7 +56,7 @@ this.Suite.prototype = new(function () {
         if ('topic' in tests) {
             throw new(Error)("missing top-level context.");
         }
-        // Count the number of vows/promises expected to fire,
+        // Count the number of vows/emitters expected to fire,
         // so we know when the tests are over.
         // We match the keys against `matcher`, to decide
         // whether or not they should be included in the test.
@@ -105,7 +105,7 @@ this.Suite.prototype = new(function () {
     this.runBatch = function (batch) {
         var topic,
             tests   = batch.tests,
-            promise = batch.promise = new(events.EventEmitter);
+            emitter = batch.emitter = new(events.EventEmitter);
 
         var that = this;
 
@@ -117,7 +117,7 @@ this.Suite.prototype = new(function () {
         // arguments list.
         // It is defined and invoked at the same time.
         // If it encounters a `topic` function, it waits for the returned
-        // promise to emit (the topic), at which point it runs the functions under it,
+        // emitter to emit (the topic), at which point it runs the functions under it,
         // passing the topic as an argument.
         (function run(ctx, lastTopic) {
             var old = false;
@@ -129,13 +129,14 @@ this.Suite.prototype = new(function () {
                 }
 
                 // Run the topic, passing the previous context topics
-                // If topic `throw`s an exception, pass it down as a value
                 try {
                     topic = topic.apply(ctx.env, ctx.topics);
                 }
+                // If an unexpected error occurs in the topic, set the return
+                // value to 'undefined' and call back with the error
                 catch (ex) {
-                    if(/ReferenceError/.test(ex)) throw ex;
-                    topic = ex;
+                    ctx.env.callback(ex);
+                    topic = undefined;
                 }
 
                 if (typeof(topic) === 'undefined') { ctx._callback = true }
@@ -151,7 +152,7 @@ this.Suite.prototype = new(function () {
                 topic = lastTopic;
             }
 
-            // If the topic doesn't return an event emitter (such as a promise),
+            // If the topic doesn't return an event emitter (such as an EventEmitter),
             // we create it ourselves, and emit the value on the next tick.
             if (! (topic &&
                    topic.constructor === events.EventEmitter)) {
@@ -229,13 +230,17 @@ this.Suite.prototype = new(function () {
                     if (topic &&
                         ctx.name !== 'on' &&
                         (!topic._vowsEmitedEvents || !topic._vowsEmitedEvents.hasOwnProperty(ctx.event))) {
-                        topic.on(ctx.event, function (ctx) {
-                            return function (val) {
-                                return run(new(Context)(vow, ctx, env), lastTopic);
+                        var runInnerContext = function(ctx){
+                            return function(val){
+                                return run(new (Context)(vow, ctx, env), lastTopic);
                             };
-                        }(ctx));
-                    } else {
-                        run(new(Context)(vow, ctx, env), lastTopic);
+                        }(ctx);
+                        topic.on(ctx.event, runInnerContext);
+                        // Run an inner context if the outer context fails, too.
+                        topic.on('error', runInnerContext);
+                    }
+                    else {
+                        run(new (Context)(vow, ctx, env), lastTopic);
                     }
                 }
             });
@@ -250,7 +255,7 @@ this.Suite.prototype = new(function () {
             exports.tryEnd(batch);
         // This is our initial, empty context
         })(new(Context)({ callback: tests, context: null, description: null }, {}));
-        return promise;
+        return emitter;
     };
 
     this.report = function () {
@@ -266,8 +271,17 @@ this.Suite.prototype = new(function () {
             that.options[k] = options[k];
         });
 
-        this.matcher  = this.options.matcher  || this.matcher;
-        this.reporter = this.options.reporter || this.reporter;
+        this.matcher = this.options.matcher  || this.matcher;
+
+        if (options.reporter) {
+          try {
+            this.reporter = typeof options.reporter === 'string'
+                ? require('./reporters/' + options.reporter)
+                : options.reporter;
+          } catch (e) {
+            console.log('Reporter was not found, defaulting to dot-matrix.');
+          }
+        }
 
         this.batches.forEach(function (batch) {
             that.parseBatch(batch, that.matcher);
@@ -381,7 +395,7 @@ this.tryEnd = function (batch) {
         function finish() {
             batch.status = 'end';
             batch.suite.report(['end']);
-            batch.promise.emit('end', batch.honored, batch.broken, batch.errored, batch.pending);
+            batch.emitter.emit('end', batch.honored, batch.broken, batch.errored, batch.pending);
         }
     }
 };
